'use strict';

var ListaMaterialController = angular.module('ListaMaterialController', []);

ListaMaterialController.controller('ListaMaterialCtrl', ['$scope', '$routeParams', 'Material', 'CacheApp',
  ($scope, $routeParams, Material, CacheApp) => {

    $scope.setMaterial = (material) => {
        material.Tipo = material.TipoSelecionado.Id;
        material.Novo = false;
        Material.setMaterial($scope.construcao.Id, material,
            (data) => {
                var retorno = data.Instance[0];
                if (retorno.Codigo != 0) {
                    $scope.msgBoxAtencao(material.Nome, retorno.Mensagem, null);
                    material.Novo = true;
                }
                else {
                    material.Id = retorno.IdMaterial;
                    material.TipoDescricao = material.TipoSelecionado.Descricao;
                    for (var i in $scope.listaUnidade)
                        if ($scope.listaUnidade[i].Id == material.IdUnidade)
                            material.UnidadeSigla = $scope.listaUnidade[i].Sigla;
                }
            });
    }

    $scope.excluirMaterial = (material) => {
        $scope.msgBoxPergunta(material.Nome, 'A exclusão do ' + material.TipoDescricao + ' implicará em possíveis alterações na composição, orçamento, financeiro e medição física.  Confirma exclusão?'
        , () => {
            var idx = $scope.materiais.indexOf(material)
            $scope.materiais.splice(idx, 1);
            Material.delMaterial($scope.construcao.Id, material.Id,
                (data) => {
                });
        }
        , () => {
        });
    }

    $scope.getListaMaterial = () => {
        var params = {
            idConstrucao: $scope.construcao.Id,
            IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined,
            nome: $scope.pesquisa,
            paginacao: $scope.paginacao
        }
        $scope.paginacao.Load = true;
        Material.getListaBasePropria(params,
            (data) => {
                if (!$scope.materiais)
                    $scope.materiais = [];
                data.Instance.forEach(l => {
                    if (!l.Importado)
                        $scope.materiais.push(l);
                })
                $scope.paginacao.Load = false;
            }
        );
    }

    $scope.aplicaFiltro = (e) => {
        clearTimeout($scope.timer); 
        $scope.timer = setTimeout( () => {
            $scope.inicializaPaginacao(); 
            $scope.getListaMaterial();
        }, 1000);
    }

    $scope.inicializaPaginacao = () => {
        $scope.materiais = undefined;
        $scope.paginacao = {
            Index: 0,
            Pages: 20
        };
    }

    $scope.getTipoMaterial = () => {
        Material.getTipoMaterial(
            (data) => {
                $scope.listaTipoMaterial = data.Instance;
            });
    }

    $scope.getListaUnidades = () => {
        Material.getListaUnidades(
            (data) => {
                $scope.listaUnidade = data.Instance;
            });
    }

    $scope.getHtmlEditar = () => {
        return '' +
            '<form class="form col-lg-12 col-md-12 col-sm-12 col-xs-12 center-block" name="formMaterial">' +
            '    <div class="form-group">' +
            '    <div class="row">' +
            '    <div class="col-lg-3 col-md-3 col-sm-3 col-xs-12">' +
            ' <label>Tipo Insumo</label>'+
            ' <select class="form-control input-lg"' +
            '   ng-model="material.TipoSelecionado"' +
            '   ng-options="tipo.Descricao for tipo in listaTipoMaterial track by tipo.Id" required>' +
            '     <option style="display:none" value=""> Selecione o tipo </option>' +
            ' </select>' +
            '    </div>' +
            '    <div class="col-lg-3 col-md-3 col-sm-3 col-xs-12">' +
            ' <br class="showMobile" />' +
            ' <label>Código</label>'+ 
            '	<input type="text" class="form-control input-lg" placeholder="Código" maxlength="20" ng-model="material.Codigo"/>' +
            '    </div>' +
            '    <div class="col-lg-3 col-md-3 col-sm-3 col-xs-12">' +
            ' <br class="showMobile" />' + 
            ' <label>Unidade</label>'+
            '	<select class="form-control input-lg" ng-model="material.IdUnidade" ng-init="material.IdUnidade = material.IdUnidade + \'\'" required>' +
            '	    <option value="" selected disabled> Unidade de referência </option>' +
            '	    <option ng-repeat="unidade in listaUnidade" value="{{unidade.Id}}">{{unidade.Descricao}} ({{unidade.Sigla}})</option>' +
            '	</select>' +
            '    </div>' +
            '    <div class="col-lg-3 col-md-3 col-sm-3 col-xs-12">' +
            ' <br class="showMobile" />' + 
            ' <label>Preço</label>'+
            '        <div class="input-group">' +
            '            <span class="input-group-addon">' +
            '                {{construcao.Moeda}}' +
            '            </span>' +
            '            <input type="text" class="form-control input-lg" placeholder="Valor Unitário" maxlength="18" ng-model="material.Valor" ui-number-mask="decimals" required>' +
            '        </div>' +
            '    </div>' +
            '    </div>' +
            '    </div>' +
            '    <div class="form-group">' +
            ' <label>Nome do Insumo</label>'+
            ' <input type="text" class="form-control input-lg" placeholder="Nome do material, equipamento ou mão-de-obra" maxlength="500" ng-model="material.Nome" required />' +
            '    </div>' +
            '    <div class="form-group text-right">' +
            '	<itemsalvar ng-click="!formMaterial.$invalid && setMaterial(material)"></itemsalvar>' +
            '	<itemcancelar ng-click="cancelarItem(material)"></itemcancelar>' +
            '    </div>' +
            '</form>';
    }

    $scope.adicionarItem = () => {
        var idCount = $scope.materiais.length;
        var maior = 0;
        for (var i in $scope.materiais) {
            if (i == 0)
                maior = parseInt($scope.materiais[i].Codigo);
            else {
                if (maior < parseInt($scope.materiais[i].Codigo))
                    maior = parseInt($scope.materiais[i].Codigo);
            }
        }
        $scope.materiais.unshift({
            Novo: true,
            Id: 0,
            Tipo: '',
            Codigo: ('0' + (maior + 1)).slice(-(maior.toString().length+1)),
            Nome: '',
            Unidade: '',
            IdCount: idCount,
            Editar: $scope.getHtmlEditar()
        });
    }

    $scope.alterarItem = (material) => {
        material.Editar = $scope.getHtmlEditar();
        material.TipoSelecionado = { Id: material.Tipo, Descricao: material.TipoDescricao };
        material.Novo = !material.Novo;
    }

    $scope.cancelarItem = (material) => {
        if (material.Id == 0) {
            var idx = $scope.materiais.indexOf(material)
            $scope.materiais.splice(idx, 1);
        }
        else
            material.Novo = !material.Novo;
    }

    $scope.getListaConstrucao = (callBack) => {
        $scope.sessao = CacheApp.getSessao()
        var params = {
            permissao: 'GET_BASEPROPRIA',
            refresh: $scope.refreshObra ? true: false
        }
        $scope.getListaObraCache(params, 
            (obra)=> {
                $scope.construcoes = obra
                callBack()
            }
        )
    }

    $scope.filtraObra = (obra) => {
        if (obra && obra.id) {
            $scope.setObraSelecionada($scope.construcoes.filter(c => c.Id == obra.id)[0])
        }
        else {
            $scope.materiais = undefined;
            $scope.construcao = undefined;
            CacheApp.delConstrucao();
            // $scope.listaRelatorio = [];
        }
    }

    $scope.setObraSelecionada = (obra) => {
        $scope.materiais = undefined
        $scope.construcao = obra
        CacheApp.setConstrucao($scope.construcao)

        // $scope.comEncargos = ($scope.construcao.EncargoSocial > 0)
        // $scope.comBDI = $scope.construcao.BDI > 0 || $scope.construcao.BDIMaoObra > 0 || $scope.construcao.BDIMaterial > 0 || $scope.construcao.BDIEquipamento > 0 || $scope.construcao.BDIServico > 0 || $scope.construcao.BDITaxa > 0
        $scope.HtmlManterObra = undefined

        $scope.loadMain()

        // $scope.listaRelatorio = []
        // $scope.listaRelatorio = $scope.reportList.filter(r => obra.Acessos.indexOf(r.Permissao) >= 0)
    }

    $scope.editarObra = () => {
        if (!$scope.HtmlManterObra)
            $scope.HtmlManterObra = `
                <manterobra mo-obra="construcao">
                </manterobra>
            `;
        $scope.openObra = !$scope.openObra;
    }

    $scope.salvarObra = () => {
        $rootScope.$broadcast('salvarObra', {});
    }

    $scope.$on('refreshComboObra', (events,args) => {
        $scope.refreshObra = true
        $scope.loadObra()
    })

    $scope.loadMain = () => {
        $scope.listaUnidade = [];

        $scope.inicializaPaginacao();
    
        $scope.getListaMaterial();
        $scope.getTipoMaterial();
        $scope.getListaUnidades();
    }

    $scope.loadObra = () => {
        $scope.ObraSelecionada = CacheApp.getConstrucao()
        CacheApp.delConstrucao()
        $scope.AtualizaConstrucao()
        $scope.getListaConstrucao(()=>{
            if ($scope.ObraSelecionada && $scope.construcoes.some(c => c.Id == $scope.ObraSelecionada.Id)) {
                $scope.listaSelecao = {
                    id: $scope.ObraSelecionada.Id, 
                    model: $scope.ObraSelecionada.Titulo, 
                    label: $scope.ObraSelecionada.Titulo,
                    checked: true
                }
                $scope.setObraSelecionada($scope.ObraSelecionada)
            }
            else
                $scope.materiais = []
        })
    }

    $scope.AcessoAndroid($routeParams, (sim) => {
        $scope.AcessoMobile = sim;

        if ($routeParams.from == 'geral') {
            $scope.loadObra()
        } else {
            $scope.construcao = CacheApp.getConstrucao()
            $scope.loadMain()
            // $scope.listaRelatorio = $scope.reportList
        }

        // $scope.construcao = CacheApp.getConstrucao();
        // $scope.listaUnidade = [];

        // $scope.inicializaPaginacao();
    
        // $scope.getListaMaterial();
        // $scope.getTipoMaterial();
        // $scope.getListaUnidades();
    });

  }]);
